@@ -4,7 +4,7 @@ use Moo::Role;
 
 {
     use version 0.77;
-    $Pod::Readme::Plugin::requires::VERSION = version->declare('v1.0.1_05');
+    $Pod::Readme::Plugin::requires::VERSION = version->declare('v1.0.1_06');
 }
 
 use CPAN::Meta;
@@ -16,7 +16,7 @@ use Pod::Readme::Types qw/ File HeadingLevel /;
 
 =head1 NAME
 
-Pod::Readme::Plugin::requires - include requirements in README
+Pod::Readme::Plugin::requires - Include requirements in README
 
 =head1 SYNOPSIS
 
@@ -78,35 +78,35 @@ has 'requires_from_file' => (
     isa     => File,
     coerce  => sub { File->coerce(@_) },
     default => 'META.yml',
-    lazy => 1,
+    lazy    => 1,
 );
 
 has 'requires_title' => (
     is      => 'rw',
     isa     => Str,
     default => 'REQUIREMENTS',
-    lazy => 1,
+    lazy    => 1,
 );
 
 has 'requires_omit_core' => (
     is      => 'rw',
     isa     => Bool,
     default => 1,
-    lazy => 1,
+    lazy    => 1,
 );
 
 has 'requires_heading_level' => (
     is      => 'rw',
     isa     => HeadingLevel,
     default => 1,
-    lazy => 1,
+    lazy    => 1,
 );
 
 has 'requires_run' => (
     is      => 'rw',
     isa     => Bool,
     default => 0,
-    lazy => 1,
+    lazy    => 1,
 );
 
 sub cmd_requires {
@@ -127,7 +127,7 @@ sub cmd_requires {
     }
 
     my $file = path( $self->base_dir, $self->requires_from_file )->stringify;
-    unless (-e $file) {
+    unless ( -e $file ) {
         die "Cannot find META.yml file at '${file}";
     }
 
@@ -179,8 +179,9 @@ sub _get_prereqs {
     my $perl = delete $prereqs{perl};
     if ( $self->requires_omit_core && $perl ) {
         foreach ( keys %prereqs ) {
+            my $ver = $prereqs{$_};
             delete $prereqs{$_}
-              if Module::CoreList->first_release($_)
+              if Module::CoreList->first_release( $_, $prereqs{$ver} )
               && version->parse( Module::CoreList->first_release($_) ) <=
               version->parse($perl);
         }
